<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\AnalyticsHub;

class SharingEnvironmentConfig extends \Google\Model
{
  protected $dcrExchangeConfigType = DcrExchangeConfig::class;
  protected $dcrExchangeConfigDataType = '';
  protected $defaultExchangeConfigType = DefaultExchangeConfig::class;
  protected $defaultExchangeConfigDataType = '';

  /**
   * @param DcrExchangeConfig
   */
  public function setDcrExchangeConfig(DcrExchangeConfig $dcrExchangeConfig)
  {
    $this->dcrExchangeConfig = $dcrExchangeConfig;
  }
  /**
   * @return DcrExchangeConfig
   */
  public function getDcrExchangeConfig()
  {
    return $this->dcrExchangeConfig;
  }
  /**
   * @param DefaultExchangeConfig
   */
  public function setDefaultExchangeConfig(DefaultExchangeConfig $defaultExchangeConfig)
  {
    $this->defaultExchangeConfig = $defaultExchangeConfig;
  }
  /**
   * @return DefaultExchangeConfig
   */
  public function getDefaultExchangeConfig()
  {
    return $this->defaultExchangeConfig;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(SharingEnvironmentConfig::class, 'Google_Service_AnalyticsHub_SharingEnvironmentConfig');
